@@ -1,6 +1,5 @@
 #![allow(unsafe_code)]
 
-use glow::HasContext;
 use std::convert::TryInto;
 
 #[derive(Copy, Clone, Debug, PartialEq, Eq)]
@@ -14,6 +13,7 @@ pub(crate) enum ShaderVersion {
 
 impl ShaderVersion {
     pub(crate) fn get(gl: &glow::Context) -> Self {
+        use glow::HasContext as _;
         let shading_lang_string =
             unsafe { gl.get_parameter_string(glow::SHADING_LANGUAGE_VERSION) };
         let shader_version = Self::parse(&shading_lang_string);
@@ -29,7 +29,9 @@ impl ShaderVersion {
     pub(crate) fn parse(glsl_ver: &str) -> Self {
         let start = glsl_ver.find(|c| char::is_ascii_digit(&c)).unwrap();
         let es = glsl_ver[..start].contains(" ES ");
-        let ver = glsl_ver[start..].splitn(2, ' ').next().unwrap();
+        let ver = glsl_ver[start..]
+            .split_once(' ')
+            .map_or(&glsl_ver[start..], |x| x.0);
         let [maj, min]: [u8; 2] = ver
             .splitn(3, '.')
             .take(2)
